@@ -20,6 +20,7 @@ import (
 	"os"
 
 	v1 "k8s.io/api/core/v1"
+	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/kubernetes"
 	typedcorev1 "k8s.io/client-go/kubernetes/typed/core/v1"
 	"k8s.io/client-go/rest"
@@ -37,16 +38,16 @@ import (
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/controller-runtime/pkg/manager/signals"
 
-	chv1 "github.com/open-cluster-management/multicloud-operators-channel/pkg/apis/apps/v1"
+	chv1 "github.com/stolostron/multicloud-operators-channel/pkg/apis/apps/v1"
 
-	"github.com/open-cluster-management/multicloud-operators-channel/pkg/apis"
-	"github.com/open-cluster-management/multicloud-operators-channel/pkg/controller"
-	"github.com/open-cluster-management/multicloud-operators-channel/pkg/utils"
-	chWebhook "github.com/open-cluster-management/multicloud-operators-channel/pkg/webhook"
+	"github.com/stolostron/multicloud-operators-channel/pkg/apis"
+	"github.com/stolostron/multicloud-operators-channel/pkg/controller"
+	"github.com/stolostron/multicloud-operators-channel/pkg/utils"
+	chWebhook "github.com/stolostron/multicloud-operators-channel/pkg/webhook"
 
-	helmsync "github.com/open-cluster-management/multicloud-operators-channel/pkg/synchronizer/helmreposynchronizer"
-	objsync "github.com/open-cluster-management/multicloud-operators-channel/pkg/synchronizer/objectstoresynchronizer"
 	placementutils "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/utils"
+	helmsync "github.com/stolostron/multicloud-operators-channel/pkg/synchronizer/helmreposynchronizer"
+	objsync "github.com/stolostron/multicloud-operators-channel/pkg/synchronizer/objectstoresynchronizer"
 )
 
 // Change below variables to serve metrics on different host or port.
@@ -117,6 +118,9 @@ func RunManager() {
 		os.Exit(1)
 	}
 
+	// Create dynamic client
+	dynamicClient := dynamic.NewForConfigOrDie(ctrl.GetConfigOrDie())
+
 	// Create channel descriptor is user for the object bucket
 	chdesc, err := utils.CreateObjectStorageChannelDescriptor()
 	if err != nil {
@@ -177,7 +181,7 @@ func RunManager() {
 	// Setup all Controllers
 	logger.Info("Setting up controller")
 
-	if err := controller.AddToManager(mgr, recorder, logf.Log.WithName("controllers"), chdesc, hsync); err != nil {
+	if err := controller.AddToManager(mgr, dynamicClient, recorder, logf.Log.WithName("controllers"), chdesc, hsync); err != nil {
 		logger.Error(err, "unable to register controllers to the manager")
 		os.Exit(exitCode)
 	}
